@@ -1,6 +1,7 @@
 #include <ctype.h>
 #include <slang/slang.h>
 #include <stdlib.h>
+#include <string.h>
 
 #include "newt.h"
 #include "newt_pr.h"
@@ -13,8 +14,6 @@ struct entry {
     int bufUsed;		/* amount of the buffer that's been used */
     int cursorPosition; 	/* cursor *in the string* on on screen */
     int firstChar;		/* first character position being shown */
-    void * callbackData;
-    newtCallback callback;
 };
 
 static void entryDraw(newtComponent co);
@@ -39,6 +38,7 @@ void newtEntrySet(newtComponent co, char * value, int cursorAtEnd) {
 	en->buf = malloc(en->bufAlloced);
 	*en->resultPtr = en->buf;
     }
+    memset(en->buf, 0, en->bufAlloced);		/* clear the buffer */
     strcpy(en->buf, value);
     en->bufUsed = strlen(value);
     en->firstChar = 0;
@@ -64,6 +64,7 @@ newtComponent newtEntry(int left, int top, char * initialValue, int width,
     co->height = 1;
     co->width = width;
     co->takesFocus = 1;
+    co->callback = NULL;
 
     co->ops = &entryOps;
 
@@ -72,7 +73,6 @@ newtComponent newtEntry(int left, int top, char * initialValue, int width,
     en->firstChar = 0;
     en->bufUsed = 0;
     en->bufAlloced = width + 1;
-    en->callback = NULL;
 
     if (initialValue && strlen(initialValue) > width) {
 	en->bufAlloced = strlen(initialValue) + 1;
@@ -91,13 +91,6 @@ newtComponent newtEntry(int left, int top, char * initialValue, int width,
     return co;
 }
 
-void newtEntryAddCallback(newtComponent co, newtCallback f, void * data) {
-    struct entry * en = co->data;
-
-    en->callback = f;
-    en->callbackData = data;
-}
-
 static void entryDraw(newtComponent co) {
     struct entry * en = co->data;
     int i;
@@ -141,7 +134,10 @@ static void entryDraw(newtComponent co) {
 	SLsmg_write_nstring(chptr, co->width);
     }
 
-    newtGotorc(co->top, co->left + (en->cursorPosition - en->firstChar));
+    if (en->flags & NEWT_ENTRY_HIDDEN)
+	newtGotorc(co->top, co->left);
+    else
+	newtGotorc(co->top, co->left + (en->cursorPosition - en->firstChar));
 }
 
 static void entryDestroy(newtComponent co) {
@@ -161,8 +157,11 @@ static struct eventResult entryEvent(struct newtComponent * co,
 	switch (ev.event) {
 	  case EV_FOCUS:
 	    /*SLtt_set_cursor_visibility(0);*/
-	    newtGotorc(co->top, co->left + 
-			        (en->cursorPosition - en->firstChar));
+	    if (en->flags & NEWT_ENTRY_HIDDEN)
+		newtGotorc(co->top, co->left);
+	    else
+		newtGotorc(co->top, co->left + 
+				(en->cursorPosition - en->firstChar));
 	    er.result = ER_SWALLOWED;
 	    break;
 
@@ -170,7 +169,7 @@ static struct eventResult entryEvent(struct newtComponent * co,
 	    /*SLtt_set_cursor_visibility(1);*/
 	    newtGotorc(0, 0);
 	    er.result = ER_SWALLOWED;
-	    if (en->callback) en->callback(co, en->callbackData);
+	    if (co->callback) co->callback(co, co->callbackData);
 	    break;
 
 	  case EV_KEYPRESS:
