@@ -2,17 +2,15 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <sys/ioctl.h>
 #include <sys/time.h>
 #include <sys/types.h>
+#include <termios.h>
 #include <unistd.h>
 
 #include "newt.h"
 #include "newt_pr.h"
 
-/* this function will be in a future version of slang - I'll just prototype
-   it myself for now XXX */
-void SLsmg_write_color_chars (unsigned short *s, unsigned int len);
-
 struct Window {
     int height, width, top, left;
     short * buffer;
@@ -36,7 +34,7 @@ struct newtColors newtDefaultColorPalette = {
 	"lightgray", "red",			/* button fg, bg */
 	"red", "lightgray",			/* active button fg, bg */
 	"yellow", "blue",			/* checkbox fg, bg */
-	"blue", "yellow",			/* active checkbox fg, bg */
+	"blue", "brown",			/* active checkbox fg, bg */
 	"yellow", "blue",			/* entry box fg, bg */
 	"blue", "lightgray",			/* label fg, bg */
 	"black", "lightgray",			/* listbox fg, bg */
@@ -66,6 +64,25 @@ static struct keymap keymap[] = {
 	{ "\033[5~",		NEWT_KEY_PGUP,		NULL },
 	{ "\033[6~",		NEWT_KEY_PGDN,		NULL },
 
+	{ "\033[[A",		NEWT_KEY_F1,		NULL },
+	{ "\033[[B",		NEWT_KEY_F2,		NULL },
+	{ "\033[[C",		NEWT_KEY_F3,		NULL },
+	{ "\033[[D",		NEWT_KEY_F4,		NULL },
+	{ "\033[[E",		NEWT_KEY_F5,		NULL },
+
+	{ "\033[11~",		NEWT_KEY_F1,		NULL },
+	{ "\033[12~",		NEWT_KEY_F2,		NULL },
+	{ "\033[13~",		NEWT_KEY_F3,		NULL },
+	{ "\033[14~",		NEWT_KEY_F4,		NULL },
+	{ "\033[15~",		NEWT_KEY_F5,		NULL },
+	{ "\033[17~",		NEWT_KEY_F6,		NULL },
+	{ "\033[18~",		NEWT_KEY_F7,		NULL },
+	{ "\033[19~",		NEWT_KEY_F8,		NULL },
+	{ "\033[20~",		NEWT_KEY_F9,		NULL },
+	{ "\033[21~",		NEWT_KEY_F10,		NULL },
+	{ "\033[23~",		NEWT_KEY_F11,		NULL },
+	{ "\033[24~",		NEWT_KEY_F12,		NULL },
+
 	{ NULL, 	0, 			NULL },	/* LEAVE this one */
 };
 static char keyPrefix = '\033';
@@ -89,11 +106,18 @@ void newtCls(void) {
 }
 
 int newtInit(void) {
+    struct winsize ws;
+
     /* use the version variable just to be sure it gets included */
     strlen(version);
 
     SLtt_get_terminfo();
 
+    if (!ioctl(1, TIOCGWINSZ, &ws)) {
+	SLtt_Screen_Rows = ws.ws_row;
+	SLtt_Screen_Cols = ws.ws_col;
+    }
+
     SLtt_Use_Ansi_Colors = 1;
 
     SLsmg_init_smg();
@@ -161,6 +185,12 @@ int newtGetKey(void) {
     *chptr++ = key;
     while (SLang_input_pending(5)) {
 	key = SLang_getkey();
+	if (key == keyPrefix) {
+	    /* he hit unknown keys too many times -- start over */
+	    memset(buf, 0, sizeof(buf));
+	    chptr = buf;
+	}
+
 	*chptr++ = key;
 
 	/* this search should use bsearch(), but when we only look through
