@@ -1,6 +1,22 @@
 #ifndef H_NEWT
 #define H_NEWT
 
+#define COLORSET_ROOT 		2
+#define COLORSET_BORDER 	3
+#define COLORSET_WINDOW		4
+#define COLORSET_SHADOW		5
+#define COLORSET_TITLE		6
+#define COLORSET_BUTTON		7
+#define COLORSET_ACTBUTTON	8
+#define COLORSET_CHECKBOX	9
+#define COLORSET_ACTCHECKBOX	10
+#define COLORSET_ENTRY		11
+#define COLORSET_LABEL		12
+#define COLORSET_LISTBOX	13
+#define COLORSET_ACTLISTBOX	14
+#define COLORSET_TEXTBOX	15
+#define COLORSET_ACTTEXTBOX	16
+
 struct newtColors {
     char * rootFg, * rootBg;
     char * borderFg, * borderBg;
@@ -53,6 +69,7 @@ void newtListitemSet(newtComponent co, char * text);
 void * newtListitemGetData(newtComponent co);
 
 newtComponent newtLabel(int left, int top, char * text);
+void newtLabelSetText(newtComponent co, char * text);
 newtComponent newtVerticalScrollbar(int left, int top, int height,
 				    int normalColorset, int thumbColorset);
 void newtScrollbarSet(newtComponent co, int where, int total);
@@ -71,14 +88,28 @@ void newtListboxSetEntry(newtComponent co, int num, char * text);
 newtComponent newtTextbox(int left, int top, int with, int height, int flags);
 void newtTextboxSetText(newtComponent co, const char * text);
 
-newtComponent newtForm(newtComponent vertBar);
+#define NEWT_FORM_NOF12		(1 << 0)
+
+struct newtExitStruct {
+    enum { NEWT_EXIT_HOTKEY, NEWT_EXIT_COMPONENT } reason;
+    union {
+	int key;
+	newtComponent co;
+    } u;
+} ;
+
+newtComponent newtForm(newtComponent vertBar, char * help, int flags);
 newtComponent newtFormGetCurrent(newtComponent co);
+void newtFormSetBackground(newtComponent co, int color);
 void newtFormSetCurrent(newtComponent co, newtComponent subco);
 void newtFormAddComponent(newtComponent form, newtComponent co);
 void newtFormAddComponents(newtComponent form, ...);
 void newtFormSetHeight(newtComponent co, int height);
-newtComponent newtRunForm(newtComponent form);
+void newtFormSetWidth(newtComponent co, int width);
+newtComponent newtRunForm(newtComponent form);		/* obsolete */
+void newtFormRun(newtComponent co, struct newtExitStruct * es);
 void newtDrawForm(newtComponent form);
+void newtFormAddHotKey(newtComponent co, int key);
 
 #define NEWT_ENTRY_SCROLL	(1 << 0)
 #define NEWT_ENTRY_HIDDEN	(1 << 1)
@@ -87,7 +118,7 @@ void newtDrawForm(newtComponent form);
 newtComponent newtEntry(int left, int top, char * initialValue, int width,
 			char ** resultPtr, int flags);
 void newtEntrySet(newtComponent co, char * value, int cursorAtEnd);
-void newtEntryAddCallback(newtComponent co, newtCallback f, void * data);
+void newtComponentAddCallback(newtComponent co, newtCallback f, void * data);
 
 /* this also destroys all of the components (including other forms) on the 
    form */
@@ -112,4 +143,17 @@ void newtFormDestroy(newtComponent form);
 #define NEWT_KEY_PGUP			NEWT_KEY_EXTRA_BASE + 11
 #define NEWT_KEY_PGDN			NEWT_KEY_EXTRA_BASE + 12
 
+#define NEWT_KEY_F1			NEWT_KEY_EXTRA_BASE + 101
+#define NEWT_KEY_F2			NEWT_KEY_EXTRA_BASE + 102
+#define NEWT_KEY_F3			NEWT_KEY_EXTRA_BASE + 103
+#define NEWT_KEY_F4			NEWT_KEY_EXTRA_BASE + 104
+#define NEWT_KEY_F5			NEWT_KEY_EXTRA_BASE + 105
+#define NEWT_KEY_F6			NEWT_KEY_EXTRA_BASE + 106
+#define NEWT_KEY_F7			NEWT_KEY_EXTRA_BASE + 107
+#define NEWT_KEY_F8			NEWT_KEY_EXTRA_BASE + 108
+#define NEWT_KEY_F9			NEWT_KEY_EXTRA_BASE + 109
+#define NEWT_KEY_F10			NEWT_KEY_EXTRA_BASE + 110
+#define NEWT_KEY_F11			NEWT_KEY_EXTRA_BASE + 111
+#define NEWT_KEY_F12			NEWT_KEY_EXTRA_BASE + 112
+
 #endif /* H_NEWT */
